@@ -1,11 +1,21 @@
 from django import template
-from django.db import models
+from django.conf import settings
 from django.core.cache import cache
+from django.db import models
+from md5 import md5 
 
 register = template.Library()
 
+def get_cache_suffix():
+    try:
+        project_hash = md5(settings.SECRET_KEY).hexdigest()
+        return "_%s" % project_hash
+    except AttributeError:
+        return "_%s" % md5().hexdigest()
+
 Chunk = models.get_model('chunks', 'chunk')
-CACHE_PREFIX = "chunk_"
+CACHE_PREFIX = 'chunks_'
+CACHE_SUFFIX = get_cache_suffix()
 
 def do_get_chunk(parser, token):
     # split_contents() knows not to split quoted strings.
@@ -30,7 +40,7 @@ class ChunkNode(template.Node):
     
     def render(self, context):
         try:
-            cache_key = CACHE_PREFIX + self.key
+            cache_key = CACHE_PREFIX + self.key + CACHE_SUFFIX
             c = cache.get(cache_key)
             if c is None:
                 c = Chunk.objects.get(key=self.key)
